package com.zd.laboratory.mapper;

import java.util.List;

import com.zd.laboratory.domain.LabPhotoInspection;

/**
 * 拍照检查附件Mapper接口
 *
 * @author zd
 * @date 2021-08-31
 */
public interface LabPhotoInspectionMapper {
    /**
     * 查询拍照检查附件
     *
     * @param id 拍照检查附件主键
     * @return 拍照检查附件
     */
    public LabPhotoInspection selectLabPhotoInspectionById(Long id);

    /**
     * 查询拍照检查附件列表
     *
     * @param labPhotoInspection 拍照检查附件
     * @return 拍照检查附件集合
     */
    public List<LabPhotoInspection> selectLabPhotoInspectionList(LabPhotoInspection labPhotoInspection);

    /**
     * 新增拍照检查附件
     *
     * @param labPhotoInspection 拍照检查附件
     * @return 结果
     */
    public int insertLabPhotoInspection(LabPhotoInspection labPhotoInspection);

    /**
     * 修改拍照检查附件
     *
     * @param labPhotoInspection 拍照检查附件
     * @return 结果
     */
    public int updateLabPhotoInspection(LabPhotoInspection labPhotoInspection);

    /**
     * 删除拍照检查附件
     *
     * @param id 拍照检查附件主键
     * @return 结果
     */
    public int deleteLabPhotoInspectionById(Long id);

    /**
     * 批量删除拍照检查附件
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteLabPhotoInspectionByIds(Long[] ids);


    /**
     * 删除拍照检查附件
     *
     * @param id 拍照检查附件主键
     * @return 结果
     */
    public int deleteLabPhotoInspectionByAccessId(Long id);
}
